#ifndef _BUTTON_H
#define _BUTTON_H

#ifndef HAVE_CONFIH_H

#define BUTTON_ENABLE_PORT	PORTD
#define BUTTON_ENABLE_DDR	DDRD
#define BUTTON_ENABLE_BIT	PD3

#define BUTTON_PIN	PIND

#endif

uint8_t _button_state;
static uint8_t _raw_button_state[8];

static inline uint8_t check_button() {
	uint8_t *p;
	int8_t i;

	bit_set(BUTTON_ENABLE_PORT, BUTTON_ENABLE_BIT);
	bit_set(BUTTON_ENABLE_DDR, BUTTON_ENABLE_BIT);
	_delay_us(1);
	p = _raw_button_state;
	for (i=0; i<8; i++,p++) {
		*p <<= 1;
		if (bit_is_set(BUTTON_PIN,i)) {
			*p |= 1;
		}
		if (*p == 0) {
			bit_clear(_button_state,i)
		} else if (*p == 0xff) {
			bit_set(_button_state,i)
		}
	}
	bit_clear(BUTTON_ENABLE_DDR, BUTTON_ENABLE_BIT);
	bit_clear(BUTTON_ENABLE_PORT, BUTTON_ENABLE_BIT);
	return _button_state;
}
#endif /* _BUTTON_H */

/* example 

          :
    TCCR0B = 0x4; // 1/256 free running
          :
          :
    uint8_t button,button_tmp;
    uint8_t button_old = 0;

    for (;;) {
          :
          :
	if (bit_is_set(TIFR0, TOV0)) {
		button = check_button();
		button_tmp = button ^ button_old;
		if (bit_is_set(button_tmp,0) && bit_is_set(button,0)) {
			usbcdc_put_pstr(PSTR("BUTTON B(1)\r\n"));
		}
		if (bit_is_set(button_tmp,1) && bit_is_set(button,1)) {
			usbcdc_put_pstr(PSTR("BUTTON Y(2)\r\n"));
		}
		if (bit_is_set(button_tmp,4) && bit_is_set(button,4)) {
			usbcdc_put_pstr(PSTR("BUTTON R(3)\r\n"));
		}
		button_old = button;
		bit_set(TIFR0, TOV0);
	}
          :
          :
    }

*/
